package de.thdeg.grademanager.gui;

import de.thdeg.grademanager.model.Course;
import de.thdeg.grademanager.model.enumeration.BachelorSemester;
import de.thdeg.grademanager.model.enumeration.CourseType;
import de.thdeg.grademanager.model.enumeration.ExamType;
import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.scene.control.*;

import java.io.IOException;
import java.util.Optional;

import static de.thdeg.grademanager.gui.CoursesOfStudyDetailsController.courseList;

public class CourseModificationController {
    @FXML
    protected ComboBox<BachelorSemester> bachelorSemesterComboBox;
    @FXML
    protected ComboBox<CourseType> courseTypeComboBox;
    @FXML
    protected ComboBox<ExamType> examTypeComboBox;
    ObservableList<BachelorSemester> bachelorSemesterList = FXCollections.observableArrayList(BachelorSemester.values());
    ObservableList<CourseType> courseTypeList = FXCollections.observableArrayList(CourseType.values());
    ObservableList<ExamType> examTypeList = FXCollections.observableArrayList(ExamType.values());

    @FXML
    protected void initialize() {
        bachelorSemesterComboBox.setItems(bachelorSemesterList);
        courseTypeComboBox.setItems(courseTypeList);
        examTypeComboBox.setItems(examTypeList);
    }


    @FXML
    protected TextField name;
    @FXML
    protected BachelorSemester bachelorSemester;
    @FXML
    protected CourseType courseType;
    @FXML
    protected TextField sws;
    @FXML
    protected TextField ects;
    @FXML
    protected ExamType examType;
    @FXML
    protected TextField warning;


    @FXML
    protected void onSaveButtonClick(ActionEvent event) throws IOException {
        if (!name.getText().isBlank() && bachelorSemesterComboBox.getValue() != null &&
                courseTypeComboBox.getValue() != null && !sws.getText().isBlank() && !ects.getText().isBlank() &&
                examTypeComboBox.getValue() != null) {
            bachelorSemester = bachelorSemesterComboBox.getValue();
            courseType = courseTypeComboBox.getValue();
            examType = examTypeComboBox.getValue();

            try {
                CoursesOfStudyDetailsController.courseList.add(new Course(1,
                        name.getText(),
                        bachelorSemester,
                        courseType,
                        Integer.parseInt(sws.getText()),
                        Integer.parseInt(ects.getText()),
                        examType));
                SwitchWindowHelper.switchTo("CoursesOfStudy Details", event);
            } catch (NumberFormatException e) {
                warning.setText("Bitte Zahlen eingeben für SWS und ECTS.");
                Alert alert = new Alert(Alert.AlertType.ERROR);
                alert.setTitle("Fehler");
                alert.setHeaderText("Bitte Zahlen eingeben für SWS und ECTS.");
                Optional<ButtonType> result = alert.showAndWait();
            }
        } else {
            warning.setText("Bitte alle Felder ausfüllen.");
            Alert alert = new Alert(Alert.AlertType.ERROR);
            alert.setTitle("Fehler");
            alert.setHeaderText("Bitte alle Felder ausfüllen.");
            Optional<ButtonType> result = alert.showAndWait();
        }
    }

    @FXML
    protected void abortAndSwitchToCoursesOfStudyDetails(ActionEvent event) throws IOException {
        Alert alert = new Alert(Alert.AlertType.CONFIRMATION);
        alert.setTitle("Bestätigung erforderlich");
        alert.setHeaderText("Daten wurden nicht gespeichert. Änderungen verwerfen?");

        ButtonType buttonTypeOne = new ButtonType("Ja");
        ButtonType buttonTypeCancel = new ButtonType("Abbrechen", ButtonBar.ButtonData.CANCEL_CLOSE);

        alert.getButtonTypes().setAll(buttonTypeOne, buttonTypeCancel);

        Optional<ButtonType> result = alert.showAndWait();
        if (result.get() == buttonTypeOne) {
            SwitchWindowHelper.switchTo("CoursesOfStudy Details", event);
        }
    }
}
